by_get API documentation — by_get 0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- by_get 0.1.0 documentation »

# by_get API documentation

by_get is written in Python3 and uses docstrings written in reStructuredText (reST) format following the Numpy docstring standard for the documentation of all classes and functions. The package is distributed through the Python Package Inventory at https://pypi.python.org/pypi/by_get using functionality provided by Python’s `setuptools` library.

All entities follow the PEP8 naming conventions using all lowercase names with underscores (`lower_case_with_underscores`) for packages, modules, methods, attributes, and functions but capitalized words (`CapWords`) for classes unless they are referring to C++ methods that are part of the PyQt4 library.

The following packages are included:

- by_get package
  - by_get module
  - version module

### Navigation

- index
- modules |
- next |
- previous |
- by_get 0.1.0 documentation »